@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::AO3;
 {
-  $WWW::FetchStory::Fetcher::AO3::VERSION = '0.1704';
+  $WWW::FetchStory::Fetcher::AO3::VERSION = '0.18';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::AO3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1704
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -89,7 +89,8 @@ sub allow {
 Parse the table-of-contents file.
 
     %info = $self->parse_toc(content=>$content,
-			 url=>$url);
+			 url=>$url,
+			 urls=>\@urls);
 
 This should return a hash containing:
 
@@ -97,8 +98,9 @@ This should return a hash containing:
 
 =item chapters
 
-An array of URLs for the chapters of the story.  (In the case where the
-story only takes one page, that will be the chapter).
+An array of URLs for the chapters of the story.  In the case where the
+story only takes one page, that will be the chapter.
+In the case where multiple URLs have been passed in, it will be those URLs.
 
 =item title
 
@@ -155,14 +157,19 @@ Figure out the URLs for the chapters of this story.
 sub parse_chapter_urls {
     my $self = shift;
     my %args = (
-	url=>'',
+	urls=>undef,
 	content=>'',
 	@_
     );
     my $content = $args{content};
     my $sid = $args{sid};
     my @chapters = ();
-    if ($content =~ m!href="(/downloads/[-\w]+/$sid/[^.]+\.html)"!)
+    if (defined $args{urls})
+    {
+	@chapters = @{$args{urls}};
+    }
+    if (@chapters == 1
+	    and $content =~ m!href="(/downloads/[-\w]+/$sid/[^.]+\.html)"!)
     {
 	@chapters = ("http://archiveofourown.org$1");
     }
