@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::DracoAndGinny;
 {
-  $WWW::FetchStory::Fetcher::DracoAndGinny::VERSION = '0.1704';
+  $WWW::FetchStory::Fetcher::DracoAndGinny::VERSION = '0.18';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::DracoAndGinny - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1704
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -87,7 +87,8 @@ sub allow {
 Parse the table-of-contents file.
 
     %info = $self->parse_toc(content=>$content,
-			 url=>$url);
+			 url=>$url,
+			 urls=>\@urls);
 
 This should return a hash containing:
 
@@ -95,8 +96,9 @@ This should return a hash containing:
 
 =item chapters
 
-An array of URLs for the chapters of the story.  (In the case where the
-story only takes one page, that will be the chapter).
+An array of URLs for the chapters of the story.  In the case where the
+story only takes one page, that will be the chapter.
+In the case where multiple URLs have been passed in, it will be those URLs.
 
 =item title
 
@@ -157,22 +159,32 @@ sub parse_chapter_urls {
     my $content = $args{content};
     my $sid = $args{sid};
     my @chapters = ();
-    my $fmt = 'http://www.dracoandginny.com/viewstory.php?action=printable&sid=%s&textsize=0&chapter=%d';
 
-    # fortunately DracoAndGinny has a sane chapter system
-    if ($content =~ m#chapter=all#s)
+    if (defined $args{urls})
     {
-	while ($content =~ m#<a href="viewstory.php\?sid=${sid}&amp;chapter=(\d+)">#sg)
-	{
-	    my $ch_num = $1;
-	    my $ch_url = sprintf($fmt, $sid, $ch_num);
-	    warn "chapter=$ch_url\n" if $self->{verbose};
-	    push @chapters, $ch_url;
-	}
+	@chapters = @{$args{urls}};
     }
-    else
+
+    if (@chapters == 1)
     {
-	@chapters = (sprintf($fmt, $sid, 1));
+	my $fmt = 'http://www.dracoandginny.com/viewstory.php?action=printable&sid=%s&textsize=0&chapter=%d';
+
+	# fortunately DracoAndGinny has a sane chapter system
+	if ($content =~ m#chapter=all#s)
+	{
+	    @chapters = ();
+	    while ($content =~ m#<a href="viewstory.php\?sid=${sid}&amp;chapter=(\d+)">#sg)
+	    {
+		my $ch_num = $1;
+		my $ch_url = sprintf($fmt, $sid, $ch_num);
+		warn "chapter=$ch_url\n" if ($self->{verbose} > 1);
+		push @chapters, $ch_url;
+	    }
+	}
+	else
+	{
+	    @chapters = (sprintf($fmt, $sid, 1));
+	}
     }
 
     return \@chapters;
