@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::FictionAlley;
 {
-  $WWW::FetchStory::Fetcher::FictionAlley::VERSION = '0.1704';
+  $WWW::FetchStory::Fetcher::FictionAlley::VERSION = '0.18';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::FictionAlley - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1704
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -144,7 +144,7 @@ sub extract_story {
     {
 	return $content;
     }
-    warn "title=$story_title\n" if $self->{verbose};
+    warn "title=$story_title\n" if ($self->{verbose} > 1);
 
     my $out = <<EOT;
 <h1>$story_title</h1>
@@ -158,7 +158,8 @@ EOT
 Parse the table-of-contents file.
 
     %info = $self->parse_toc(content=>$content,
-			 url=>$url);
+			 url=>$url,
+			 urls=>\@urls);
 
 This should return a hash containing:
 
@@ -166,8 +167,9 @@ This should return a hash containing:
 
 =item chapters
 
-An array of URLs for the chapters of the story.  (In the case where the
-story only takes one page, that will be the chapter).
+An array of URLs for the chapters of the story.  In the case where the
+story only takes one page, that will be the chapter.
+In the case where multiple URLs have been passed in, it will be those URLs.
 
 =item title
 
@@ -216,11 +218,19 @@ sub parse_chapter_urls {
     );
     my $content = $args{content};
     my @chapters = ();
-    while ($content =~ m#<a href\s*=\s*"(http://www.fictionalley.org/authors/\w+/\w+\.html)"\s*class\s*=\s*"chapterlink">#g)
+    if (defined $args{urls})
     {
-	my $ch_url = $1;
-	warn "chapter=$ch_url\n" if $self->{verbose};
-	push @chapters, $ch_url;
+	@chapters = @{$args{urls}};
+    }
+    if (@chapters == 1)
+    {
+	@chapters = ();
+	while ($content =~ m#<a href\s*=\s*"(http://www.fictionalley.org/authors/\w+/\w+\.html)"\s*class\s*=\s*"chapterlink">#g)
+	{
+	    my $ch_url = $1;
+	    warn "chapter=$ch_url\n" if ($self->{verbose} > 1);
+	    push @chapters, $ch_url;
+	}
     }
 
     return \@chapters;
