@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::Gutenberg;
 {
-  $WWW::FetchStory::Fetcher::Gutenberg::VERSION = '0.1704';
+  $WWW::FetchStory::Fetcher::Gutenberg::VERSION = '0.18';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::Gutenberg - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1704
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -89,7 +89,8 @@ sub allow {
 Parse the table-of-contents file.
 
     %info = $self->parse_toc(content=>$content,
-			 url=>$url);
+			 url=>$url,
+			 urls=>\@urls);
 
 This should return a hash containing:
 
@@ -97,8 +98,9 @@ This should return a hash containing:
 
 =item chapters
 
-An array of URLs for the chapters of the story.  (In the case where the
-story only takes one page, that will be the chapter).
+An array of URLs for the chapters of the story.  In the case where the
+story only takes one page, that will be the chapter.
+In the case where multiple URLs have been passed in, it will be those URLs.
 
 =item title
 
@@ -145,10 +147,17 @@ sub parse_chapter_urls {
     );
     my $content = $args{content};
     my @chapters = ();
-    if ($args{url} =~ m{http://www.gutenberg.org/ebooks/(\d+)})
+    if (defined $args{urls})
     {
-	my $sid = $1;
-	@chapters = ("http://www.gutenberg.org/files/${sid}/${sid}-h/${sid}-h.htm");
+	@chapters = @{$args{urls}};
+    }
+    if (@chapters == 1)
+    {
+	if ($args{url} =~ m{http://www.gutenberg.org/ebooks/(\d+)})
+	{
+	    my $sid = $1;
+	    @chapters = ("http://www.gutenberg.org/files/${sid}/${sid}-h/${sid}-h.htm");
+	}
     }
 
     return \@chapters;
