@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::HPAdultFanfiction;
 {
-  $WWW::FetchStory::Fetcher::HPAdultFanfiction::VERSION = '0.1704';
+  $WWW::FetchStory::Fetcher::HPAdultFanfiction::VERSION = '0.18';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::HPAdultFanfiction - fetching module for WWW::FetchStor
 
 =head1 VERSION
 
-version 0.1704
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -121,10 +121,10 @@ sub extract_story {
     my $title = $args{title};
 
     my $chapter = $self->parse_ch_title(%args);
-    warn "chapter=$chapter\n" if $self->{verbose};
+    warn "chapter=$chapter\n" if ($self->{verbose} > 1);
 
     my $author = $self->parse_author(%args);
-    warn "author=$author\n" if $self->{verbose};
+    warn "author=$author\n" if ($self->{verbose} > 1);
 
     my $story = '';
     if ($content =~ m!<td colspan="3" bgcolor="F4EBCC">\s*<font color="#003333">Disclaimer:[^<]+</font>\s*</td>\s*</tr>\s*<tr>\s*<td colspan="3">\s*<p>&nbsp;</p>\s*</td>\s*</tr>\s*<tr>\s*<td colspan="3" bgcolor="F4EBCC">\s*(.*?)<tr class='catdis'>!s)
@@ -160,7 +160,8 @@ sub extract_story {
 Parse the table-of-contents file.
 
     %info = $self->parse_toc(content=>$content,
-			 url=>$url);
+			 url=>$url,
+			 urls=>\@urls);
 
 This should return a hash containing:
 
@@ -168,8 +169,9 @@ This should return a hash containing:
 
 =item chapters
 
-An array of URLs for the chapters of the story.  (In the case where the
-story only takes one page, that will be the chapter).
+An array of URLs for the chapters of the story.  In the case where the
+story only takes one page, that will be the chapter.
+In the case where multiple URLs have been passed in, it will be those URLs.
 
 =item title
 
@@ -249,21 +251,29 @@ sub parse_chapter_urls {
     my $content = $args{content};
     my $sid = $args{sid};
     my @chapters = ();
-    my $fmt = 'http://hp.adultfanfiction.net/story.php?no=%d&chapter=%d';
-    my $max_chapter = 0;
-    while ($content =~ m#<option value='story\.php\?no=${sid}&chapter=(\d+)'#gs)
+    if (defined $args{urls})
     {
-	my $a_ch = $1;
-	if ($a_ch > $max_chapter)
-	{
-	    $max_chapter = $a_ch;
-	}
+	@chapters = @{$args{urls}};
     }
-    for (my $ch = 1; $ch <= $max_chapter; $ch++)
+    if (@chapters == 1)
     {
-	my $ch_url = sprintf($fmt, $sid, $ch);
-	warn "chapter=$ch_url\n" if $self->{verbose};
-	push @chapters, $ch_url;
+	@chapters = ();
+	my $fmt = 'http://hp.adultfanfiction.net/story.php?no=%d&chapter=%d';
+	my $max_chapter = 0;
+	while ($content =~ m#<option value='story\.php\?no=${sid}&chapter=(\d+)'#gs)
+	{
+	    my $a_ch = $1;
+	    if ($a_ch > $max_chapter)
+	    {
+		$max_chapter = $a_ch;
+	    }
+	}
+	for (my $ch = 1; $ch <= $max_chapter; $ch++)
+	{
+	    my $ch_url = sprintf($fmt, $sid, $ch);
+	    warn "chapter=$ch_url\n" if ($self->{verbose} > 1);
+	    push @chapters, $ch_url;
+	}
     }
 
     return \@chapters;
