@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::PetulantPoetess;
 {
-  $WWW::FetchStory::Fetcher::PetulantPoetess::VERSION = '0.1704';
+  $WWW::FetchStory::Fetcher::PetulantPoetess::VERSION = '0.18';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::PetulantPoetess - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1704
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -87,7 +87,8 @@ sub allow {
 Parse the table-of-contents file.
 
     %info = $self->parse_toc(content=>$content,
-			 url=>$url);
+			 url=>$url,
+			 urls=>\@urls);
 
 This should return a hash containing:
 
@@ -95,8 +96,9 @@ This should return a hash containing:
 
 =item chapters
 
-An array of URLs for the chapters of the story.  (In the case where the
-story only takes one page, that will be the chapter).
+An array of URLs for the chapters of the story.  In the case where the
+story only takes one page, that will be the chapter.
+In the case where multiple URLs have been passed in, it will be those URLs.
 
 =item title
 
@@ -155,14 +157,22 @@ sub parse_chapter_urls {
     my $content = $args{content};
     my $sid = $args{sid};
     my @chapters = ();
-    # PetulantPoetess does not have a sane chapter system
-    my $fmt = 'http://www.thepetulantpoetess.com/viewstory.php?action=printable&sid=%d';
-    while ($content =~ m#viewstory.php\?sid=(\d+)#sg)
+    if (defined $args{urls})
     {
-	my $ch_sid = $1;
-	my $ch_url = sprintf($fmt, $ch_sid);
-	warn "chapter=$ch_url\n" if $self->{verbose};
-	push @chapters, $ch_url;
+	@chapters = @{$args{urls}};
+    }
+    if (@chapters == 1)
+    {
+	@chapters = ();
+	# PetulantPoetess does not have a sane chapter system
+	my $fmt = 'http://www.thepetulantpoetess.com/viewstory.php?action=printable&sid=%d';
+	while ($content =~ m#viewstory.php\?sid=(\d+)#sg)
+	{
+	    my $ch_sid = $1;
+	    my $ch_url = sprintf($fmt, $ch_sid);
+	    warn "chapter=$ch_url\n" if ($self->{verbose} > 1);
+	    push @chapters, $ch_url;
+	}
     }
 
     return \@chapters;
