@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::TardisBigBang3;
 {
-  $WWW::FetchStory::Fetcher::TardisBigBang3::VERSION = '0.1704';
+  $WWW::FetchStory::Fetcher::TardisBigBang3::VERSION = '0.18';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::TardisBigBang3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1704
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -125,7 +125,8 @@ sub extract_story {
 Parse the table-of-contents file.
 
     %info = $self->parse_toc(content=>$content,
-			 url=>$url);
+			 url=>$url,
+			 urls=>\@urls);
 
 This should return a hash containing:
 
@@ -133,8 +134,9 @@ This should return a hash containing:
 
 =item chapters
 
-An array of URLs for the chapters of the story.  (In the case where the
-story only takes one page, that will be the chapter).
+An array of URLs for the chapters of the story.  In the case where the
+story only takes one page, that will be the chapter.
+In the case where multiple URLs have been passed in, it will be those URLs.
 
 =item title
 
@@ -207,21 +209,24 @@ sub parse_chapter_urls {
     my $content = $args{content};
     my $sid = $args{sid};
     my @chapters = ();
-    if ($content =~ m#part=2#)
+    if (defined $args{urls})
     {
-	my $fmt = $args{url};
-	$fmt =~ s/part=\d+/part=\%d/;
-	while ($content =~ m#storyID=${sid}\&part=(\d+)">Part#sg)
-	{
-	    my $ch_num = $1;
-	    my $ch_url = sprintf($fmt, $ch_num);
-	    warn "chapter=$ch_url\n" if $self->{verbose};
-	    push @chapters, $ch_url;
-	}
+	@chapters = @{$args{urls}};
     }
-    else
+    if (@chapters == 1)
     {
-	push @chapters, $args{url};
+	if ($content =~ m#part=2#)
+	{
+	    my $fmt = $args{url};
+	    $fmt =~ s/part=\d+/part=\%d/;
+	    while ($content =~ m#storyID=${sid}\&part=(\d+)">Part#sg)
+	    {
+		my $ch_num = $1;
+		my $ch_url = sprintf($fmt, $ch_num);
+		warn "chapter=$ch_url\n" if ($self->{verbose} > 1);
+		push @chapters, $ch_url;
+	    }
+	}
     }
 
     return \@chapters;
