@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::Teaspoon;
 {
-  $WWW::FetchStory::Fetcher::Teaspoon::VERSION = '0.1704';
+  $WWW::FetchStory::Fetcher::Teaspoon::VERSION = '0.18';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::Teaspoon - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1704
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -108,7 +108,7 @@ sub extract_story {
 	$title = $1;
 	$user= $2;
     }
-    warn "user=$user, title=$title\n" if $self->{verbose};
+    warn "user=$user, title=$title\n" if ($self->{verbose} > 1);
 
     my $story = '';
     if ($content =~ m#(<strong>Summary:.*)<u>Disclaimer:</u>#s)
@@ -167,7 +167,8 @@ EOT
 Parse the table-of-contents file.
 
     %info = $self->parse_toc(content=>$content,
-			 url=>$url);
+			 url=>$url,
+			 urls=>\@urls);
 
 This should return a hash containing:
 
@@ -175,8 +176,9 @@ This should return a hash containing:
 
 =item chapters
 
-An array of URLs for the chapters of the story.  (In the case where the
-story only takes one page, that will be the chapter).
+An array of URLs for the chapters of the story.  In the case where the
+story only takes one page, that will be the chapter.
+In the case where multiple URLs have been passed in, it will be those URLs.
 
 =item title
 
@@ -347,20 +349,28 @@ sub parse_chapter_urls {
     my $sid = $args{sid};
     my $fmt = $args{fmt};
     my @chapters = ();
-    # fortunately Teaspoon has a sane chapter system
-    if ($content =~ m#chapter=all#s)
+    if (defined $args{urls})
     {
-	while ($content =~ m#<a href="viewstory.php\?sid=${sid}&amp;chapter=(\d+)">#sg)
-	{
-	    my $ch_num = $1;
-	    my $ch_url = sprintf($fmt, $sid, $ch_num);
-	    warn "chapter=$ch_url\n" if $self->{verbose};
-	    push @chapters, $ch_url;
-	}
+	@chapters = @{$args{urls}};
     }
-    else
+    if (@chapters == 1)
     {
-	@chapters = (sprintf($fmt, $sid, 1));
+	# fortunately Teaspoon has a sane chapter system
+	if ($content =~ m#chapter=all#s)
+	{
+	    @chapters = ();
+	    while ($content =~ m#<a href="viewstory.php\?sid=${sid}&amp;chapter=(\d+)">#sg)
+	    {
+		my $ch_num = $1;
+		my $ch_url = sprintf($fmt, $sid, $ch_num);
+		warn "chapter=$ch_url\n" if ($self->{verbose} > 1);
+		push @chapters, $ch_url;
+	    }
+	}
+	else
+	{
+	    @chapters = (sprintf($fmt, $sid, 1));
+	}
     }
 
     return \@chapters;
